@@ -40,9 +40,10 @@ c       Hence, this programme can be run automatically (non-interactively) now.
       dimension gb(nParamTotal)
       dimension y(nParamTotal)
       dimension h(nParamTotal,nParamTotal)
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
+      common/four/frestart,mrestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/two/fx,fy
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
 
       im=imArg
@@ -78,21 +79,23 @@ c       Hence, this programme can be run automatically (non-interactively) now.
       nrestartArg = nrestart
       end
  
-      subroutine mini(yy,xx,mm,sv,ob,gb,fxs,y,h)
+      subroutine mini(yy,xx,sv,ob,gb,fxs,y,h)
 c       contains the main loop of this iterative program. 
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
-      dimension yy(nn,nt),xx(nn,nt,nr),mm(nn),sv(n)
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/two/fx,fy
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
+      common/four/frestart,mrestart,nrestart
+      dimension yy(nn,nt),xx(nn,nt,nr),sv(n)
       dimension ob(n),gb(n),x(:),y(n),s(:)
       dimension h(n,n),delx(:),delg(:),gx(:),gy(:)
       allocatable :: x,s,delx,delg,gx,gy
       allocate(x(n),s(n))
       allocate(delx(n),delg(n),gx(n),gy(n))
       do 98 i=1,n   
-      gx(i)=0.0  
-      gy(i)=0.0  
+      gx(i)=dble(0)  
+      gy(i)=dble(0)
+      delx(i)=dble(0)  
   98    continue
   107 if ((igrid.eq.1).and.(nrestart.eq.0)) then
       call grid(x,y,yy,xx,ob,gb)  
@@ -111,19 +114,20 @@ c       contains the main loop of this iterative program.
       iter=0 
       if (im.eq.1) call der1(x,gx,yy,xx) 
       if (im.eq.2) call der2(x,gx,yy,xx) 
-      if (iprint.ne.0) write(6,*)
-      if (iprint.ne.0) write(6,301) iter,nfunct,-fy   
-      nc=1   
-  305 if (iprint.ne.0) write(6,302) (y(i),i=nc,min(n,nc+4))   
-      nc=nc+5
-      if(nc.le.n) goto 305   
+      if (iprint.ne.0) then 
+      call intpr( 'iteration', -1, iter, 1 )
+      call intpr( 'function evaluations', -1, nfunct, 1 )
+      call dblepr( 'log-likelihood value', -1, -fy, 1 )   
+      call dblepr( 'parameters', -1, y, n )
+      endif
       if (maxit.eq.0) goto 70
    5    do 20 i=1,n 
       do 10 j=1,n
-   10   h(i,j)=0.0 
-   20   h(i,i)=1.0 
-      if(iprint.ne.0) write(6,2100)  
- 2100   format(' gradient step')  
+   10   h(i,j)=dble(0) 
+   20   h(i,i)=dble(1) 
+      if(iprint.ne.0) then
+      call intpr( 'gradient step', -1, 0, 0 )
+      endif
       do 30 i=1,n
    30   s(i)=-gx(i)
    40 icode=0
@@ -133,14 +137,14 @@ c       contains the main loop of this iterative program.
       icode=10
       goto 70
       endif  
-   7    if(fy.gt.fx) goto 5
+      if(fy.gt.fx) goto 5
       if (im.eq.1) call der1(y,gy,yy,xx)
       if (im.eq.2) call der2(y,gy,yy,xx) 
       call convrg(ipass,x,y) 
       if (ipass.eq.1.) then
-      if ((iter.eq.1).and.(icode.eq.5).and.(nrestart.le.10)) then
-      write(6,109) frestart
-  109 format('restarting with starting values multiplied by',e16.8)
+      if ((iter.eq.1).and.(icode.eq.5).and.(nrestart.le.mrestart)) then
+      call dblepr( 'restarting with starting values multiplied by',
+     $  -1, frestart, 1 )
       do 108 i=1,n
       sv(i)=x(i)*frestart
   108 continue
@@ -151,13 +155,12 @@ c       contains the main loop of this iterative program.
       endif
       endif
       if (iprint.ne.0) then
-      printcon=float(iter)/float(iprint)-float(iter/iprint)
-      if (printcon.eq.0.0) then   
-      write(6,301) iter,nfunct,-fy   
-      nc=1   
-  304   write(6,302) (y(i),i=nc,min(n,nc+4))   
-      nc=nc+5
-      if(nc.le.n) goto 304   
+      printcon=dble(iter)/dble(iprint)-dble(iter/iprint)
+      if (printcon.eq.dble(0)) then   
+      call intpr( 'iteration', -1, iter, 1 )
+      call intpr( 'function evaluations', -1, nfunct, 1 )
+      call dblepr( 'log-likelihood value', -1, -fy, 1 )   
+      call dblepr( 'parameters', -1, y, n )
       endif
       endif  
       do 50 i=1,n
@@ -168,18 +171,17 @@ c       contains the main loop of this iterative program.
       fx=fy  
       call eta(h,delx,delg,gx)
       do 60 i=1,n
-      s(i)=0.0   
+      s(i)=dble(0)   
       do 60 j=1,n
    60   s(i)=s(i)-h(i,j)*gy(j)
       goto 40
    70   continue  
-      if (iprint.ne.0) write(6,301) iter,nfunct,-fy
-      nc=1   
-  303 if (iprint.ne.0)  write(6,302) (y(i),i=nc,min(n,nc+4))   
-      nc=nc+5
-      if(nc.le.n) goto 303   
-  301   format(' iteration = ',i5,'  func evals =',i7,'  llf =',e16.8) 
-  302   format(4x,5e15.8)  
+      if (iprint.ne.0) then 
+      call intpr( 'iteration', -1, iter, 1 )
+      call intpr( 'function evaluations', -1, nfunct, 1 )
+      call dblepr( 'log-likelihood value', -1, -fy, 1 )
+      call dblepr( 'parameters', -1, y, n )
+      endif
       deallocate(x,s,delx,delg,gx,gy)
       return 
       end
@@ -190,9 +192,8 @@ c       the program is halted when the proportional change in the log-
 c       likelihood and in each of the parameters is no greater than   
 c       a specified tolerance.
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/two/fx,fy
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
       dimension x(n),y(n)
       xtol=tol   
@@ -217,18 +218,17 @@ c       a specified tolerance.
       subroutine eta(h,delx,delg,gx) 
 c       calculates the direction matrix (p).  
       implicit double precision (a-h,o-z)
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
       dimension h(n,n),delx(n),delg(n),gx(n)
       dimension hdg(:),dgh(:),hgx(:)  
       allocatable :: hdg,dgh,hgx
       allocate(hdg(n),dgh(n),hgx(n))
-      dxdg=0.0   
-      dghdg=0.0  
+      dxdg=dble(0)   
+      dghdg=dble(0)  
       do 20 i=1,n
-      hdg(i)=0.0 
-      dgh(i)=0.0 
+      hdg(i)=dble(0) 
+      dgh(i)=dble(0) 
       do 10 j=1,n
       hdg(i)=hdg(i)-h(i,j)*delg(j)   
    10   dgh(i)=dgh(i)+delg(j)*h(j,i)   
@@ -240,26 +240,26 @@ c       calculates the direction matrix (p).
       do 117 i=1,n   
   117   h(i,i)=dabs(h(i,i))
       do 132 i=1,n   
-      hgx(i)=0.0 
+      hgx(i)=dble(0) 
       do 132 j=1,n   
       hgx(i)=hgx(i)+h(i,j)*gx(j) 
   132   continue   
-      hgxx=0.
-      gxx=0. 
+      hgxx=dble(0)
+      gxx=dble(0) 
       do 133 i=1,n   
       hgxx=hgxx+hgx(i)**2
       gxx=gxx+gx(i)**2   
   133   continue   
-      c=0.   
+      c=dble(0)   
       do 134 i=1,n   
       c=c+hgx(i)*gx(i)   
   134   continue   
-      c=c/(hgxx*gxx)**0.5
-      if(dabs(c).lt.1.0/bignum) then
-      write(6,*) 'ill-conditioned eta'   
+      c=c/(hgxx*gxx)**dble(0.5)
+      if(dabs(c).lt.dble(1)/bignum) then
+      call intpr( 'ill-conditioned eta', -1, 0, 0 )
       do 136 i=1,n   
       do 137 j=1,n   
-  137   h(i,j)=0.0
+  137   h(i,j)=dble(0)
   136   h(i,i)=delx(i)/gx(i)  
       endif  
       deallocate(hdg,dgh,hgx)
@@ -270,29 +270,29 @@ c       calculates the direction matrix (p).
 c       unidimensional search (coggin) to determine optimal step length
 c       determines the step length (t) using a unidimensional search. 
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/two/fx,fy
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
       dimension x(n),y(n),s(n),gx(n),delx(n)
       dimension yy(nn,nt),xx(nn,nt,nr)
       iexit=0
       ntol=0 
       ftol=tol2  
-      ftol2=ftol/100.0   
+      ftol2=ftol/dble(100)   
       fa=fx  
       fb=fx  
       fc=fx  
-      da=0.0 
-      db=0.0 
-      dc=0.0 
+      da=dble(0) 
+      db=dble(0) 
+      dc=dble(0) 
       k=-2   
       m=0
       step=step1 
       d=step 
       if(indic.eq.2.or.iter.eq.0) goto 1 
-      dxnorm=0.0 
-      snorm=0.0  
+      dxnorm=dble(0) 
+      snorm=dble(0)  
       do 102 i=1,n   
       dxnorm=dxnorm+delx(i)*delx(i)  
   102   snorm=snorm+s(i)*s(i) 
@@ -305,8 +305,8 @@ c       determines the step length (t) using a unidimensional search.
       if (im.eq.1) call fun1(y,f,yy,xx) 
       if (im.eq.2) call fun2(y,f,yy,xx) 
       if (f.ne.f) then
-      write(6,2505)
- 2505 format(' function value in search procedure is NaN')
+      call intpr( 'function value in search procedure is NaN', 
+     $   -1, 0, 0 )
       return
       endif
       k=k+1
@@ -314,8 +314,10 @@ c       determines the step length (t) using a unidimensional search.
    3    do 4 i=1,n  
    4    y(i)=x(i)+da*s(i)   
       fy=fa  
-      if(iprint.ne.0) write(6,2100)  
- 2100   format(' search failed. fn val indep of search direction')
+      if(iprint.ne.0) then
+      call intpr( 'search failed. fn val indep of search direction',
+     $  -1, 0, 0 )
+      endif
       goto 326   
    5    fc=fb   
       fb=fa  
@@ -323,7 +325,7 @@ c       determines the step length (t) using a unidimensional search.
       dc=db  
       db=da  
       da=d   
-      d=2.0*d+step   
+      d=dble(2)*d+step   
       goto 1 
    6    if(k) 7,8,9 
    7    fb=f
@@ -344,7 +346,7 @@ c       determines the step length (t) using a unidimensional search.
       fc=fb  
       fb=fa  
       fa=f   
-   10   d=0.5*(da+db)  
+   10   d=dble(0.5)*(da+db)  
       do 11 i=1,n
    11   y(i)=x(i)+d*s(i)   
       if (im.eq.1) call fun1(y,f,yy,xx) 
@@ -354,8 +356,10 @@ c       determines the step length (t) using a unidimensional search.
    14   y(i)=x(i)+db*s(i)  
       fy=fb  
       if(iexit.eq.1) goto 32 
-      if(iprint.ne.0) write(6,2500)  
- 2500   format(' search failed. loc of min limited by rounding')  
+      if(iprint.ne.0) then
+      call intpr( 'search failed. loc of min limited by rounding',
+     $ -1, 0, 0 )
+      endif
       goto 325   
    15   if(f-fb) 16,13,17  
    16   fc=fb  
@@ -376,16 +380,17 @@ c       determines the step length (t) using a unidimensional search.
       dc=d   
    21   a=fa*(db-dc)+fb*(dc-da)+fc*(da-db) 
       if(a) 22,30,22
-   22   d=0.5*((db*db-dc*dc)*fa+(dc*dc-da*da)*fb+(da*da-db*db)*fc)/a   
+   22   d=dble(0.5)*
+     $  ((db*db-dc*dc)*fa+(dc*dc-da*da)*fb+(da*da-db*db)*fc)/a   
       if((da-d)*(d-dc)) 13,13,23 
    23   do 24 i=1,n
    24   y(i)=x(i)+d*s(i)   
       if (im.eq.1) call fun1(y,f,yy,xx) 
       if (im.eq.2) call fun2(y,f,yy,xx) 
       if(dabs(fb)-ftol2) 25,25,26
-   25   a=1.0  
+   25   a=dble(1)  
       goto 27
-   26   a=1.0/fb   
+   26   a=dble(1)/fb   
    27   if((dabs(fb-f)*a)-ftol) 28,28,12   
    28   iexit=1
       if(f-fb) 29,13,13  
@@ -398,43 +403,45 @@ c       determines the step length (t) using a unidimensional search.
       if(y(i).ne.x(i)) goto 325  
    99   continue   
       goto 33
-  325   if(ntol.ne.0.and.iprint.eq.1) write(6,3000) ntol  
- 3000   format(1x,'tolerance reduced ',i2,' time(s)')
+  325   if(ntol.ne.0.and.iprint.eq.1) then
+      call intpr( 'tolerance reduced so many time(s):', -1, ntol, 1 )
+      endif
   326   if(fy.lt.fx) return   
       do 101 i=1,n   
       if(s(i).ne.-gx(i)) return  
   101   continue  
-      write(6,5000)  
- 5000   format(' search failed on gradient step, termination')
+      call intpr( 'search failed on gradient step, termination',
+     $  -1, 0, 0 )
       icode=6
       return 
    33   if(ntol.eq.10) goto 34
       iexit=0
       ntol=ntol+1
-      ftol=ftol/10.  
+      ftol=ftol/dble(10)  
       goto 12
-  34    if(iprint.ne.0) write(6,2000)   
- 2000   format(' pt better than entering pt cannot be found')
+  34    if(iprint.ne.0) then
+      call intpr( 'pt better than entering pt cannot be found', 
+     $  -1, 0, 0 )
+      endif
       icode=5
       return 
       end
  
-      subroutine check(b,xx)
+      subroutine check(b)
 c       checks if params are out of bounds & adjusts if required. 
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
-      dimension b(n),xx(nn,nt,nr)
+      dimension b(n)
       n1=nr+1
       n2=nr+2
       bi=dsqrt(bignum) 
-      if(b(n1).le.0.0) b(n1)=1.0/bi  
-      if(b(n2).le.1.0/bi) b(n2)=1.0/bi   
-      if(b(n2).ge.1.0-1.0/bi) b(n2)=1.0-1.0/bi   
+      if(b(n1).le.dble(0)) b(n1)=dble(1)/bi  
+      if(b(n2).le.dble(1)/bi) b(n2)=dble(1)/bi   
+      if(b(n2).ge.dble(1)-dble(1)/bi) b(n2)=dble(1)-dble(1)/bi   
       bound=bmu*dsqrt(b(n1)*b(n2))
-      if((im.eq.1).and.(nmu.eq.1).and.(bmu.gt.0.0)) then
+      if((im.eq.1).and.(nmu.eq.1).and.(bmu.gt.dble(0))) then
       n3=nr+3
       if(b(n3).gt.bound) b(n3)=bound
       if(b(n3).lt.-bound) b(n3)=-bound
@@ -446,54 +453,54 @@ c       checks if params are out of bounds & adjusts if required.
 c       calculates the negative of the log-likelihood function of the
 c       error components model.
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       data pi/3.1415926/ 
       dimension b(n),yy(nn,nt),xx(nn,nt,nr)
-      call check(b,xx)  
-      a=0.0 
-      f=dfloat(nn)    
-      fnt=dfloat(nt)
-      ftot=dfloat(nob) 
+      call check(b)  
+      a=dble(0) 
+      f=dble(nn)    
+      fnt=dble(nt)
+      ftot=dble(nob) 
       s2=b(nb+1)
       g=b(nb+2)
-      u=0.0
-      e=0.0
+      u=dble(0)
+      e=dble(0)
       if (nmu.eq.1) then 
       u=b(nb+3)
       if (neta.eq.1) e=b(nb+4)
       else
       if (neta.eq.1) e=b(nb+3)
       endif
-      sc=1.
-      if (ipc.eq.2) sc=-1.
-      a=0.5*ftot*(dlog(2.0*pi)+dlog(s2))    
-      a=a+0.5*(ftot-f)*dlog(1.0-g)    
-      z=u/(s2*g)**0.5
+      sc=dble(1)
+      if (ipc.eq.2) sc=-dble(1)
+      a=dble(0.5)*ftot*(dlog(dble(2)*pi)+dlog(s2))    
+      a=a+dble(0.5)*(ftot-f)*dlog(dble(1)-g)    
+      z=u/(s2*g)**dble(0.5)
       a=a+f*dislog(z)
-      a=a+0.5*f*z**2  
-      a2=0.0
+      a=a+dble(0.5)*f*z**2  
+      a2=dble(0)
       do 132 i=1,nn   
-      epr=0.0    
+      epr=dble(0)    
       do 103 l=1,nt   
-      if (xx(i,l,1).ne.0.0) then
+      if (xx(i,l,1).ne.dble(0)) then
       ee=yy(i,l)  
       do 102 j=1,nb   
       ee=ee-b(j)*xx(i,l,j)   
   102   continue   
-      epr=epr+ee*dexp(-e*(dfloat(l)-fnt))   
+      epr=epr+ee*dexp(-e*(dble(l)-fnt))   
       end if
   103   continue   
-      epe=0.0
+      epe=dble(0)
       do 101 l=1,nt   
-      if (xx(i,l,1).ne.0.0) epe=epe+dexp(-2.0*e*(dfloat(l)-fnt))    
+      if (xx(i,l,1).ne.dble(0)) epe=epe+dexp(-dble(2)*e*(dble(l)-fnt))    
   101   continue   
-      zi=(u*(1.0-g)-sc*g*epr)/(g*(1.0-g)*s2*(1.0+(epe-1.0)*g))**0.5
-      a=a+0.5*dlog(1.0+(epe-1.0)*g)   
+      zi=(u*(dble(1)-g)-sc*g*epr)/
+     $  (g*(dble(1)-g)*s2*(dble(1)+(epe-dble(1))*g))**dble(0.5)
+      a=a+dble(0.5)*dlog(dble(1)+(epe-dble(1))*g)   
       a=a-dislog(zi)
       do 133 l=1,nt   
-      if (xx(i,l,1).ne.0.0) then
+      if (xx(i,l,1).ne.dble(0)) then
       ee=yy(i,l)  
       do 134 j=1,nb   
       ee=ee-b(j)*xx(i,l,j)   
@@ -501,9 +508,9 @@ c       error components model.
       a2=a2+ee**2 
       end if
  133    continue    
-      a=a-0.5*zi**2   
+      a=a-dble(0.5)*zi**2   
  132    continue    
-      a=a+0.5*a2/((1.0-g)*s2) 
+      a=a+dble(0.5)*a2/((dble(1)-g)*s2) 
       nfunct=nfunct+1 
       return
       end   
@@ -512,20 +519,19 @@ c       error components model.
 c       calculates the first-order partial derivatives of the negative
 c       of the log-likelihood function of the error components model.
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       dimension b(n),gx(n),yy(nn,nt),xx(nn,nt,nr) 
-      call check(b,xx)  
-      f=dfloat(nn)    
-      ftot=dfloat(nob) 
-      fnt=dfloat(nt)  
+      call check(b)  
+      f=dble(nn)    
+      ftot=dble(nob) 
+      fnt=dble(nt)  
       n1=nr+1
       n2=nr+2
       s2=b(n1)
       g=b(n2)
-      u=0.0
-      e=0.0
+      u=dble(0)
+      e=dble(0)
       if (nmu.eq.1) then 
       n3=nr+3
       u=b(n3)
@@ -539,52 +545,55 @@ c       of the log-likelihood function of the error components model.
       e=b(n4)
       endif
       endif
-      sc=1.
-      if (ipc.eq.2) sc=-1.
-      z=u/(s2*g)**0.5
+      sc=dble(1)
+      if (ipc.eq.2) sc=-dble(1)
+      z=u/(s2*g)**dble(0.5)
       do 106 j=1,n        
-      gx(j)=0.0
+      gx(j)=dble(0)
  106    continue
-      gx(n1)=0.5*ftot/s2-0.5*f*(dendis(z)+z)*z/s2
-      gx(n2)=-.5*(ftot-f)/(1.-g)-.5*f*(dendis(z)+z)*z/g
+      gx(n1)=dble(0.5)*ftot/s2-dble(0.5)*f*(dendis(z)+z)*z/s2
+      gx(n2)=-dble(0.5)*(ftot-f)/(dble(1)-g)-
+     $  dble(0.5)*f*(dendis(z)+z)*z/g
       
       do 105 i=1,nn
-      epr=0.0    
-      epe=0.0
+      epr=dble(0)    
+      epe=dble(0)
       do 103 l=1,nt   
-      if (xx(i,l,1).ne.0.0) then
+      if (xx(i,l,1).ne.dble(0)) then
       ee=yy(i,l)  
       do 102 j=1,nb   
       ee=ee-b(j)*xx(i,l,j)   
   102   continue   
-      epr=epr+ee*dexp(-e*(dfloat(l)-fnt))   
-      epe=epe+dexp(-2.0*e*(dfloat(l)-fnt))    
+      epr=epr+ee*dexp(-e*(dble(l)-fnt))   
+      epe=epe+dexp(-dble(2)*e*(dble(l)-fnt))    
       end if
   103   continue   
-      zi=(u*(1.0-g)-sc*g*epr)/(g*(1.0-g)*s2*(1.0+(epe-1.0)*g))**0.5
+      zi=(u*(dble(1)-g)-sc*g*epr)/
+     $  (g*(dble(1)-g)*s2*(dble(1)+(epe-dble(1))*g))**dble(0.5)
       
       do 132 j=1,nb   
       do 134 l=1,nt   
-      if(xx(i,l,1).ne.0.0) then
+      if(xx(i,l,1).ne.dble(0)) then
       ee=yy(i,l)  
       do 135 k=1,nb   
       ee=ee-xx(i,l,k)*b(k)   
  135    continue    
-      gx(j)=gx(j)-xx(i,l,j)*ee/(s2*(1.-g))
+      gx(j)=gx(j)-xx(i,l,j)*ee/(s2*(dble(1)-g))
       endif
  134    continue    
-      xpe=0.0
+      xpe=dble(0)
       do 146 l=1,nt
-      if(xx(i,l,1).ne.0.0)xpe=xpe+xx(i,l,j)*dexp(-e*(dfloat(l)-fnt))
+      if(xx(i,l,1).ne.dble(0))xpe=xpe+xx(i,l,j)*dexp(-e*(dble(l)-fnt))
  146    continue
       d=(dendis(zi)+zi)*g*xpe*sc
-      gx(j)=gx(j)-d/(g*(1.0-g)*s2*(1.0+(epe-1.0)*g))**0.5   
+      gx(j)=gx(j)-d/
+     $  (g*(dble(1)-g)*s2*(dble(1)+(epe-dble(1))*g))**dble(0.5)   
  132    continue    
       
-      gx(n1)=gx(n1)+.5*(dendis(zi)+zi)*zi/s2
-      ss=0.0
+      gx(n1)=gx(n1)+dble(0.5)*(dendis(zi)+zi)*zi/s2
+      ss=dble(0)
       do 138 l=1,nt   
-      if(xx(i,l,1).ne.0.0) then
+      if(xx(i,l,1).ne.dble(0)) then
       ee=yy(i,l)  
       do 139 j=1,nb   
       ee=ee-xx(i,l,j)*b(j)   
@@ -592,30 +601,32 @@ c       of the log-likelihood function of the error components model.
       ss=ss+ee**2 
       endif
  138    continue
-      gx(n1)=gx(n1)-0.5*ss/((1.0-g)*s2**2)   
+      gx(n1)=gx(n1)-dble(0.5)*ss/((dble(1)-g)*s2**2)   
       
-      gx(n2)=gx(n2)+0.5*ss/((1.0-g)**2*s2)   
-      gx(n2)=gx(n2)+0.5*(epe-1.0)/(1.0+(epe-1.0)*g)  
-      d=g*(1.-g)*(1.0+(epe-1.0)*g) 
+      gx(n2)=gx(n2)+dble(0.5)*ss/((dble(1)-g)**2*s2)   
+      gx(n2)=gx(n2)+dble(0.5)*(epe-dble(1))/(dble(1)+(epe-dble(1))*g)  
+      d=g*(dble(1)-g)*(dble(1)+(epe-dble(1))*g) 
       dzi=-(u+sc*epr)*d   
-      c=0.5*(u*(1.0-g)-sc*g*epr) 
-      dzi=dzi-c*((1.0-2.0*g)+(epe-1.0)*g*(2.0-3.0*g))  
-      dzi=dzi/(d**1.5*s2**0.5)    
+      c=dble(0.5)*(u*(dble(1)-g)-sc*g*epr) 
+      dzi=dzi-c*
+     $  ((dble(1)-dble(2)*g)+(epe-dble(1))*g*(dble(2)-dble(3)*g))  
+      dzi=dzi/(d**dble(1.5)*s2**dble(0.5))    
       gx(n2)=gx(n2)-(dendis(zi)+zi)*dzi
   
       if (nmu.eq.1) then  
-      gx(n3)=gx(n3)+1./(s2*g)**0.5*(dendis(z)+z)
-      d=(dendis(zi)+zi)*(1.-g)
-      gx(n3)=gx(n3)-d/(g*(1.-g)*s2*(1.+(epe-1.)*g))**.5  
+      gx(n3)=gx(n3)+dble(1)/(s2*g)**dble(0.5)*(dendis(z)+z)
+      d=(dendis(zi)+zi)*(dble(1)-g)
+      gx(n3)=gx(n3)-d/
+     $  (g*(dble(1)-g)*s2*(dble(1)+(epe-dble(1))*g))**dble(0.5) 
       end if
   
       if (neta.eq.1) then 
-      de=0.0
-      d=0.0 
+      de=dble(0)
+      d=dble(0) 
       do 152 l=1,nt   
       if (xx(i,l,1).eq.1) then  
-      t=dfloat(l)
-      de=de-2.0*(t-fnt)*dexp(-2.0*e*(t-fnt))    
+      t=dble(l)
+      de=de-dble(2)*(t-fnt)*dexp(-dble(2)*e*(t-fnt))    
       ee=yy(i,l)  
       do 153 j=1,nb   
       ee=ee-xx(i,l,j)*b(j)   
@@ -623,13 +634,13 @@ c       of the log-likelihood function of the error components model.
       d=d+(t-fnt)*dexp(-e*(t-fnt))*ee
       end if
   152   continue   
-      dd=(g*(1.0-g)*s2*(1.0+(epe-1.0)*g)) 
+      dd=(g*(dble(1)-g)*s2*(dble(1)+(epe-dble(1))*g)) 
       d=d*g*dd*sc
-      c=u*(1.0-g)-sc*g*epr  
-      c=c*0.5*g**2*(1.0-g)*s2*de    
-      dzi=(d-c)/dd**1.5    
+      c=u*(dble(1)-g)-sc*g*epr  
+      c=c*dble(0.5)*g**2*(dble(1)-g)*s2*de    
+      dzi=(d-c)/dd**dble(1.5)
       gx(n4)=gx(n4)-(dendis(zi)+zi)*dzi
-      gx(n4)=gx(n4)+g/2.0*de/(1.0+(epe-1.0)*g)   
+      gx(n4)=gx(n4)+g/dble(2)*de/(dble(1)+(epe-dble(1))*g)   
       end if
   105   continue
   
@@ -642,37 +653,36 @@ c       of the log-likelihood function of the error components model.
 c       calculates the negative of the log-likelihood function of the
 c       TE effects model.
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       dimension b(n),yy(nn,nt),xx(nn,nt,nr)
       data pi/3.1415926/ 
-      call check(b,xx)  
+      call check(b)  
       s2=b(nr+1) 
       g=b(nr+2)  
-      ss=(g*(1.-g)*s2)**0.5  
-      sc=1.0
-      if (ipc.eq.2) sc=-1.0
-      a=0.   
+      ss=(g*(dble(1)-g)*s2)**dble(0.5)  
+      sc=dble(1)
+      if (ipc.eq.2) sc=-dble(1)
+      a=dble(0)   
       do 10 i=1,nn   
       do 10 l=1,nt
-      if (xx(i,l,1).ne.0.0) then
-      xb=0.  
+      if (xx(i,l,1).ne.dble(0)) then
+      xb=dble(0)  
       do 11 j=1,nb   
       xb=xb+xx(i,l,j)*b(j) 
    11   continue   
       ee=(yy(i,l)-xb)
-      zd=0.  
+      zd=dble(0)  
       if (nz.ne.0) then  
       do 12 j=nb+1,nr
       zd=zd+xx(i,l,j)*b(j) 
    12   continue   
       endif  
-      us=(1.-g)*zd-sc*g*ee  
-      d=zd/(g*s2)**0.5   
+      us=(dble(1)-g)*zd-sc*g*ee  
+      d=zd/(g*s2)**dble(0.5)   
       ds=us/ss   
-      a=a-0.5*dlog(2.*pi)-0.5*dlog(s2)-(dislog(d)-dislog(ds))
-     +  -0.5*(ee+sc*zd)**2/s2 
+      a=a-dble(0.5)*dlog(dble(2)*pi)-dble(0.5)*dlog(s2)-
+     $  (dislog(d)-dislog(ds))-dble(0.5)*(ee+sc*zd)**2/s2 
       endif
    10   continue   
       a=-a   
@@ -684,35 +694,34 @@ c       TE effects model.
 c       calculates the first-order partial derivatives of the negative
 c       of the log-likelihood function of the TE effects model.   
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       dimension b(n),gx(n),yy(nn,nt),xx(nn,nt,nr)
-      call check(b,xx)  
+      call check(b)  
       s2=b(nr+1) 
       g=b(nr+2)  
-      ss=(g*(1.-g)*s2)**0.5  
-      sc=1.0
-      if (ipc.eq.2) sc=-1.0
+      ss=(g*(dble(1)-g)*s2)**dble(0.5)  
+      sc=dble(1)
+      if (ipc.eq.2) sc=-dble(1)
       do 9 j=1,n 
-      gx(j)=0.   
+      gx(j)=dble(0)   
    9    continue   
       do 10 i=1,nn   
       do 10 l=1,nt
-      if (xx(i,l,1).ne.0.0) then
-      xb=0.  
+      if (xx(i,l,1).ne.dble(0)) then
+      xb=dble(0)  
       do 11 j=1,nb   
       xb=xb+xx(i,l,j)*b(j) 
    11   continue   
       ee=(yy(i,l)-xb)
-      zd=0.  
+      zd=dble(0)  
       if (nz.ne.0) then  
       do 12 j=nb+1,nr
       zd=zd+xx(i,l,j)*b(j) 
    12   continue   
       endif  
-      us=(1.-g)*zd-sc*g*ee  
-      d=zd/(g*s2)**0.5   
+      us=(dble(1)-g)*zd-sc*g*ee  
+      d=zd/(g*s2)**dble(0.5)   
       ds=us/ss   
       do 13 j=1,nb   
       gx(j)=gx(j)+xx(i,l,j)*((ee+sc*zd)/s2+sc*dendis(ds)*g/ss)
@@ -720,15 +729,15 @@ c       of the log-likelihood function of the TE effects model.
       if (nz.ne.0) then  
       do 14 j=nb+1,nr
       gx(j)=gx(j)-xx(i,l,j)*((sc*ee+zd)/s2+dendis(d)/(g*s2)
-     +  **0.5-dendis(ds)*(1.-g)/ss)
+     +  **dble(0.5)-dendis(ds)*(dble(1)-g)/ss)
    14   continue   
       endif  
-      gx(nr+1)=gx(nr+1)-0.5/s2*(1.-(dendis(d)*d-dendis(ds)
+      gx(nr+1)=gx(nr+1)-dble(0.5)/s2*(dble(1)-(dendis(d)*d-dendis(ds)
      +  *ds)-(ee+sc*zd)**2/s2)
-      gx(nr+2)=gx(nr+2)+0.5*(dendis(d)*d/g-dendis(ds)
-     +  /ss*(zd/g+sc*ee/(1.-g)))
-c       gx(nr+2)=gx(nr+2)+0.5*(dendis(d)*d/g-dendis(ds)*
-c    +  (2.*(ee+zd)/ss+ds*(1.-2.*g)/(g*(1.-g))))
+      gx(nr+2)=gx(nr+2)+dble(0.5)*(dendis(d)*d/g-dendis(ds)
+     +  /ss*(zd/g+sc*ee/(dble(1)-g)))
+c       gx(nr+2)=gx(nr+2)+dble(0.5)*(dendis(d)*d/g-dendis(ds)*
+c    +  (dble(2)*(ee+zd)/ss+ds*(dble(1)-dble(2)*g)/(g*(dble(1)-g))))
       endif
    10   continue   
       do 15 j=1,n
@@ -744,10 +753,8 @@ c    +  (2.*(ee+zd)/ss+ds*(1.-2.*g)/(g*(1.-g))))
 c       accepts instructions from the terminal or from a file and 
 c       also reads data from a file.  
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
-      character chst
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       dimension yy(:,:),xx(:,:,:),mm(:),sv(:),xxd(:)
       dimension startVal(nStartVal)
       dimension dataTable(nRowData,nColData)
@@ -759,9 +766,12 @@ c       also reads data from a file.
       igrid=1
       nz=0
       if ((nn*nt).lt.nob) then   
-      write(6,*) ' the total number of obsns exceeds the product of'    
-      write(6,*) ' the number of firms by the number of years - bye!'   
-      stop  
+      call intpr( 'the total number of obsns exceeds the product of',
+     $  -1, 0, 0 )
+      call intpr( 'the number of firms by the number of years - bye!',
+     $  -1, 0, 0 )
+      icode=101
+      return  
       end if
       if (im.eq.1) then
       nb=nb+1
@@ -776,9 +786,12 @@ c       also reads data from a file.
       n=nr+2
       endif
       if (n.ne.nParamTotal) then
-      write(6,*) 'internal error: calculated variable ''n'''
-      write(6,*) 'is not equal to argument ''nParamTotal'''
-      stop
+      call intpr( 'internal error: calculated variable ''n''',
+     $  -1, 0, 0 )
+      call intpr( 'is not equal to argument ''nParamTotal''', 
+     $ -1, 0, 0 )
+      icode=102
+      return
       endif
       allocate (sv(n))
       if (nStartVal.eq.n) then
@@ -787,32 +800,33 @@ c       also reads data from a file.
       sv(i)=startVal(i)
   148   continue  
       else if (nStartVal.gt.1) then
-      write(6,*) 'wrong number of starting values'
-      stop
+      call intpr( 'wrong number of starting values', -1, 0, 0 )
+      icode=103
+      return
       endif
       allocate(yy(nn,nt),xx(nn,nt,nr),mm(nn),xxd(nr))
       do 135 i=1,nn
       mm(i)=0
       do 135 l=1,nt
-      xx(i,l,1)=0.0
+      xx(i,l,1)=dble(0)
   135   continue
       do 134 k=1,nob  
-      ndat=nr
-      if(im.eq.2) ndat=nr-nmu
       fii=dataTable(k,1)
       ftt=dataTable(k,2)
       yyd=dataTable(k,3)
-      xxd(2:)=dataTable(k,4:)
+      do 143 i=2,nr
+      xxd(i)=dataTable(k,2+i)
+  143 continue
       i=int(fii)   
       l=int(ftt)   
       mm(i)=mm(i)+1
-      xx(i,l,1)=1.0
+      xx(i,l,1)=dble(1)
       yy(i,l)=yyd
       do 136 j=2,nb
       xx(i,l,j)=xxd(j)
   136   continue
       if ((im.eq.2).and.(nz.gt.0)) then
-      if (nmu.eq.1) xx(i,l,nb+1)=1.0
+      if (nmu.eq.1) xx(i,l,nb+1)=dble(1)
       if ((nz-nmu).gt.0) then
       do 154 j=nb+nmu+1,nr
       xx(i,l,j)=xxd(j-nmu)
@@ -820,27 +834,34 @@ c       also reads data from a file.
       endif
       endif
       if (i.lt.1) then  
-      write(6,*) ' error - a firm number is < 1'    
-      stop  
+      call intpr( 'error - a firm number is < 1', -1, 0, 0 )
+      icode=104 
+      return
       else if (i.gt.nn) then 
-      write(6,*) ' error - a firm number is > number of firms'
-      stop  
+      call intpr( 'error - a firm number is > number of firms', 
+     $  -1, 0, 0 )
+      icode=105
+      return
       else if (l.lt.1) then  
-      write(6,*) ' error - a period number is < 1'  
-      stop  
+      call intpr( 'error - a period number is < 1', -1, 0, 0 )
+      icode=106
+      return
       else if (l.gt.nt) then 
-      write(6,*) ' error - a period number is > number of periods' 
-      stop  
+      call intpr( 'error - a period number is > number of periods',
+     $  -1, 0, 0 )
+      icode=107
+      return
       end if
   134   continue   
       do 149 i=1,nn   
       if (mm(i).eq.0) then  
-      write(6,66) i   
-   66   format(' error - there are no observations on firm ',i6)
-      stop  
+      call intpr( 'error - there are no observations on firm',
+     $  -1, i, 1 )
+      icode=108
+      return
       end if
   149   continue   
-      call mini(yy,xx,mm,sv,ob,gb,fxs,y,h)
+      call mini(yy,xx,sv,ob,gb,fxs,y,h)
       deallocate(yy,xx,mm,sv,xxd)
       return 
       end
@@ -850,33 +871,33 @@ c       also reads data from a file.
       subroutine grid(x,y,yy,xx,ob,gb)
 c       does a grid search across gamma
       implicit double precision (a-h,o-z)
-      common/one/fx,fy,nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
-      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode,
-     $  mrestart,frestart,nrestart
+      common/one/nn,nz,nb,nr,nt,nob,nmu,neta,ipc,im
+      common/two/fx,fy
+      common/three/n,nfunct,ndrv,iter,indic,iprint,igrid,maxit,icode
       common/five/tol,tol2,bmu,bignum,step1,gridno,igrid2
       dimension x(n),y(n),yy(nn,nt),xx(nn,nt,nr),ob(n),gb(n)
       data pi/3.1415926/ 
       n1=nr+1
       n2=nr+2
-      sc=1.0
-      if (ipc.eq.2) sc=-1.0
-      var=ob(nb+1)*float(nob-nb)/float(nob)
+      sc=dble(1)
+      if (ipc.eq.2) sc=-dble(1)
+      var=ob(nb+1)*dble(nob-nb)/dble(nob)
       b0=ob(1)   
       do 131 i=1,nb+1
       y(i)=ob(i) 
   131   continue   
       do 132 i=nb+1,nr   
-      y(i)=0.
+      y(i)=dble(0)
   132   continue   
       fx=bignum  
       y6b=gridno 
-      y6t=1.0-gridno 
+      y6t=dble(1)-gridno 
       nloop=ceiling((y6t-y6b+gridno)/gridno)
       do 137 j=1,nloop
       y6=y6b+(j-1)*gridno
       y(n2)=y6   
-      y(n1)=var/(1.-2.*y(n2)/pi) 
-      c=(y(n2)*y(n1)*2/pi)**0.5  
+      y(n1)=var/(dble(1)-dble(2)*y(n2)/pi) 
+      c=(y(n2)*y(n1)*2/pi)**dble(0.5)  
       y(1)=b0+c*sc
       if (im.eq.1) call fun1(y,fy,yy,xx) 
       if (im.eq.2) call fun2(y,fy,yy,xx) 
@@ -888,15 +909,15 @@ c       does a grid search across gamma
       end if 
   137   continue   
       if(igrid2.eq.1) then   
-      bb1=x(n2)-gridno/2.0   
-      bb2=x(n2)+gridno/2.0   
-      bb3=gridno/10.0 
+      bb1=x(n2)-gridno/dble(2)   
+      bb2=x(n2)+gridno/dble(2)   
+      bb3=gridno/dble(10) 
       nloop=ceiling((bb2-bb1+bb3)/bb3)
       do 140 j=1,nloop
       y6=bb1+(j-1)*bb3
       y(n2)=y6   
-      y(n1)=var/(1.-2.*y(n2)/pi) 
-      c=(y(n2)*y(n1)*2/pi)**0.5  
+      y(n1)=var/(dble(1)-dble(2)*y(n2)/pi) 
+      c=(y(n2)*y(n1)*2/pi)**dble(0.5)  
       y(1)=b0+c*sc
       if (im.eq.1) call fun1(y,fy,yy,xx) 
       if (im.eq.2) call fun2(y,fy,yy,xx) 
